==> cmsmadesimple-1.8.2p0.tgz: cms/modules/FileManager/lang/ext/sv_SE.php <==
<?php
$lang['friendlyname'] = 'Filhanteraren';
$lang['permission'] = 'Anv&auml;ndning av modulen Filhanteraren';
$lang['permissionadvanced'] = 'Avancerad anv&auml;ndning av modulen Filhanteraren';
$lang['moddescription'] = 'Hantering av filer och underkataloger i CMSMS filsektion f&ouml;r uppladdade filer';
$lang['installed'] = 'Filhanteraren i version %s &auml;r installerad';
$lang['postinstall'] = 'Modulen Filhanteraren installerades';
$lang['uninstalled'] = 'Modulen Filhanteraren avinstallerad';
$lang['really_uninstall'] = '&Auml;r du s&auml;ker p&aring; att du vill avinstallera modulen Filhanteraren?';
$lang['upgraded'] = 'Modulen Filhanteraren uppgraderades till version %s';
$lang['fileview'] = 'Filvy';
$lang['switchtofileview'] = 'V&auml;xla till filvy';
$lang['settings'] = 'Inst&auml;llningar';
$lang['savesettings'] = 'Spara inst&auml;llningar';
$lang['filename'] = 'Filnamn';
$lang['fileinfo'] = 'Filinformation';
$lang['fileowner'] = 'Fil&auml;gare';
$lang['fileperms'] = 'R&auml;ttigheter';
$lang['filesize'] = 'Storlek';
$lang['filedate'] = 'Datum';
$lang['actions'] = 'Handlingar';
$lang['delete'] = 'Ta bort';
$lang['notwritable'] = 'Inte skrivbar';
$lang['filetoobig'] = '&auml;r f&ouml;r stor. Uppladdningen avbr&ouml;ts.';
$lang['unknown'] = 'Ok&auml;nd';
$lang['fileoutsideuploads'] = 'Du &auml;r inte till&aring;ten att modifiera filer utanf&ouml;r uploads-mappen! (Det kr&auml;ver r&auml;ttigheten Advanced File Management)';
$lang['writable'] = 'Skrivbar';
$lang['writeprotected'] = 'Skrivskyddad';
$lang['bytes'] = 'byte';
$lang['kb'] = 'kb ';
$lang['mb'] = 'mb ';
$lang['files'] = 'filer';
$lang['bytesin'] = 'bytes i';
$lang['in'] = 'i';
$lang['file'] = 'fil';
$lang['fileno'] = 'Filnummer';
$lang['subdirs'] = 'underkataloger';
$lang['subdir'] = 'underkatalog';
$lang['and'] = 'och';
$lang['confirmsingledelete'] = '&Auml;r du s&auml;ker?';
$lang['confirmsingledirdelete'] = '&Auml;r du s&auml;ker p&aring; att du vill ta bort den h&auml;r katalogen?';
$lang['dirtreedeletesuccess'] = 'Katalogen och dess inneh&aring;ll togs bort.';
$lang['dirtreedeletefail'] = 'Ett fel uppstod d&aring; den h&auml;r katalogen skulle tas bort. En del av dess inneh&aring;ll kan ha tagits bort.';
$lang['singlefiledeletesuccess'] = 'Filen togs bort';
$lang['filedeletesuccess'] = 'togs bort';
$lang['singlefiledeletefail'] = 'Ett fel uppstod d&aring; filen skulle tas bort';
$lang['filedeletefail'] = ' togs inte bort p&aring; grund av ett fel';
$lang['singledirdeletesuccess'] = 'Katalogen togs bort';
$lang['singledirdeletefail'] = 'Ett fel uppstod d&aring; katalogen skulle tas bort (&auml;r den tom?)';
$lang['deleteselected'] = 'Ta bort de markerade filerna';
$lang['confirmselected'] = '&Auml;r du s&auml;ker?';
$lang['confirmdeleteselected'] = '&Auml;r du s&auml;ker p&aring; att de valda filerna ska tas bort?';
$lang['deleteselectedcancelled'] = 'Borttagning av de valda filerna &aring;ngrad';
$lang['recursetext'] = 'Rekursivt (upprepa) i undermappar';
$lang['nofilesselected'] = 'Inga filer valda';
$lang['moveselected'] = 'Flytta de valda filerna';
$lang['copyselected'] = 'Kopiera de valda filerna';
$lang['selecttargetdir'] = 'V&auml;lj m&aring;lmapp f&ouml;r flytta/kopiera';
$lang['movedto'] = 'flytta till';
$lang['copiedto'] = 'kopiera till';
$lang['couldnotmove'] = 'kunde inte tas bort';
$lang['couldnotcopy'] = 'kunde inte kopieras';
$lang['rename'] = 'Byt namn';
$lang['newname'] = 'Nytt namn:';
$lang['renamesuccess'] = 'Filen har bytt namn';
$lang['renamefailure'] = 'Byte av filnamn misslyckades';
$lang['renamecancelled'] = 'Byte av filnamn &aring;ngrat';
$lang['owner'] = '&Auml;gare';
$lang['group'] = 'Grupp';
$lang['others'] = 'Andra';
$lang['newpermissions'] = 'Nya r&auml;ttigheter:';
$lang['setpermissions'] = 'St&auml;ll in r&auml;ttigheter';
$lang['permissionstyle'] = 'R&auml;ttighetsstil';
$lang['rwxstyle'] = 'rwx-stil';
$lang['755style'] = '755-stil';
$lang['quickmode'] = 'Snabbt chmod (som 777)';
$lang['chmod'] = 'Byt r&auml;ttigheter';
$lang['chmodselected'] = 'Byt r&auml;ttigheter f&ouml;r valda filer';
$lang['chmodsuccess'] = 'Filen fick nya r&auml;ttigheter';
$lang['chmodfailure'] = 'Byte av r&auml;ttigheter f&ouml;r fil misslyckades';
$lang['chmodcancelled'] = 'Byte av r&auml;ttigheter &aring;ngrat';
$lang['dirchmodfailmulti'] = 'Byte av r&auml;ttigheter f&ouml;r mappen misslyckades, n&aring;got av dess inneh&aring;ll kan dock ha f&aring;tt nya r&auml;ttigheter.';
$lang['dirchmodsuccessmulti'] = 'Byte av r&auml;ttigheter f&ouml;r mappen och dess inneh&aring;ll genomf&ouml;rt';
$lang['dirchmodsuccess'] = 'Mappen har f&aring;tt nya r&auml;ttigheter';
$lang['dirchmodfailure'] = 'Byte av r&auml;ttigheter f&ouml;r mappen misslyckades';
$lang['dirnotemptyconfirm'] = 'Den h&auml;r katalogen &auml;r inte tom. Vill du verkligen ta bort allt inneh&aring;ll, inklusive eventuella underkataloger?';
$lang['dirtreedeletecancelled'] = 'Borttagningen avbr&ouml;ts.';
$lang['imsure'] = 'Jag &auml;r s&auml;ker';
$lang['cancel'] = 'Avbryt';
$lang['ok'] = 'Ok';
$lang['uploadnewfile'] = 'Ladda upp ny fil/nya filer:';
$lang['unpackafterupload'] = 'F&ouml;rs&ouml;k packa upp fil efter uppladdning (bara tgz- och flertalet zip-filer)?';
$lang['uploadsuccess'] = 'laddades upp';
$lang['uploadfail'] = 'laddades inte upp';
$lang['unpacksuccess'] = 'packades upp';
$lang['unpackfail'] = 'misslyckades med f&ouml;ljande fel:';
$lang['packfileopenfail'] = 'Kunde inte &ouml;ppna den packade filen. Kontrollera formatet.';
$lang['packfilewritefail'] = 'Kunde inte &ouml;ppna filen &amp;s f&ouml;r skrivning';
$lang['containsillegalchars'] = 'Filnamn inneh&aring;ller ett eller flera otill&aring;tna tecken (&#039;,&quot;,+,*,\,/,&amp;,$)';
$lang['currentpath'] = 'G&auml;llande s&ouml;kv&auml;g:';
$lang['newdirname'] = 'Skapa ny katalog:';
$lang['newdirsuccess'] = 'Katalogen skapades';
$lang['newdirfail'] = 'Ett fel uppstod d&aring; katalogen skulle skapas';
$lang['invalidnewdir'] = 'Namn p&aring; nya kataloger kan inte inneh&aring;lla /, \ och &#039;..&#039; ';
$lang['filedateformat'] = 'm/d/&Aring; T:m:s';
$lang['iconsize'] = 'Ikonstorlek';
$lang['smallicons'] = 'Sm&aring; ikoner';
$lang['largeicons'] = 'Stora ikoner';
$lang['thousanddelimiter'] = 'Tusentalsavgr&auml;nsare';
$lang['none'] = 'Inga';
$lang['space'] = 'mellanslag';
$lang['showthumbnails'] = 'Visa tumnaglar';
$lang['showthumbnailshelp'] = 'N&auml;r detta &auml;r aktiverat kommer tumnaglar av bildfiler visas om de finns, och sj&auml;lva tumnagelfilen kommer att d&ouml;ljas. Vid inaktivering visas alla filer.';
$lang['uploadfilesto'] = 'Laddar upp filer till:';
$lang['uploadview'] = 'Ladda upp filer';
$lang['uploadboxes'] = 'Antal uploadboxar';
$lang['nothinguploaded'] = 'Ingenting laddades upp';
$lang['unsupportedarchive'] = 'Arkivformatet st&ouml;ds inte';
$lang['uploadmethod'] = 'Uppladdningsmetod';
$lang['uploaderstandard'] = 'Standardmetod f&ouml;r html-inmatning (till&aring;ter uppackning)';
$lang['enableadvanced'] = 'M&ouml;jligg&ouml;r avancerat l&auml;ge?';
$lang['advancedhelp'] = 'L&aring;ter dig f&aring; tillg&aring;ng till CMSMS hela filsystem, inte bara /upload/ (om till&aring;tet)';
$lang['showhiddenfileshelp'] = 'Fungerar bara med avancerat l&auml;ge p&aring;';
$lang['showhiddenfiles'] = 'Visa dolda filer';
$lang['settingsconfirmsingledelete'] = 'Bekr&auml;fta borttaning av enstaka fil?';
$lang['settingssaved'] = 'Inst&auml;llningarna sparades';
$lang['help'] = '		<h3>Vad g&ouml;r den h&auml;r modulen?</h3>
		<p>Den h&auml;r modulen tillhandah&aring;ller funktioner f&ouml;r filhantering.</p>
		<h3>Hur anv&auml;nder jag den?</h3>
		<p>V&auml;ljd den fr&aring;n Inneh&aring;ll i administrationssidan.</p>';
$lang['utma'] = '156861353.1215732140.1254944166.1255300348.1255385924.5';
$lang['utmz'] = '156861353.1254951124.3.3.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php/topic,32040.0.html|utmcmd=referral';
$lang['qca'] = 'P0-1490037384-1254944166056';
$lang['utmb'] = '156861353.1.10.1255385924';
$lang['utmc'] = '156861353';
?>

==> cmsmadesimple-1.9.4p4.tgz: cms/modules/FileManager/lang/ext/sv_SE.php <==
<?php
$lang['friendlyname'] = 'Filhanteraren';
$lang['permission'] = 'Anv&auml;ndning av modulen Filhanteraren';
$lang['permissionadvanced'] = 'Avancerad anv&auml;ndning av modulen Filhanteraren';
$lang['moddescription'] = 'Hantering av filer och underkataloger i CMSMS filsektion f&ouml;r uppladdade filer';
$lang['installed'] = 'Filhanteraren i version %s &auml;r installerad';
$lang['postinstall'] = 'Modulen Filhanteraren installerades';
$lang['uninstalled'] = 'Modulen Filhanteraren avinstallerad';
$lang['really_uninstall'] = '&Auml;r du s&auml;ker p&aring; att du vill avinstallera modulen Filhanteraren?';
$lang['upgraded'] = 'Modulen Filhanteraren uppgraderades till version %s';
$lang['fileview'] = 'Filvy';
$lang['switchtofileview'] = 'V&auml;xla till filvy';
$lang['settings'] = 'Inst&auml;llningar';
$lang['savesettings'] = 'Spara inst&auml;llningar';
$lang['postletexists'] = 'Varning! V&auml;nligen bort modules/FileManager/katalog helt, eftersom detta har varit f&ouml;r&aring;ldrad i m&aring;nga, m&aring;nga versioner.';
$lang['filename'] = 'Filnamn';
$lang['fileinfo'] = 'Filinformation';
$lang['fileowner'] = 'Fil&auml;gare';
$lang['fileperms'] = 'R&auml;ttigheter';
$lang['filesize'] = 'Storlek';
$lang['filedate'] = 'Datum';
$lang['actions'] = 'Handlingar';
$lang['delete'] = 'Ta bort';
$lang['notwritable'] = 'Inte skrivbar';
$lang['afileistoobig'] = 'En fil &auml;r f&ouml;r stor. Uppladdningen avbr&ouml;ts.';
$lang['unknown'] = 'Ok&auml;nd';
$lang['fileoutsideuploads'] = 'Du &auml;r inte till&aring;ten att modifiera filer utanf&ouml;r uploads-mappen! (Det kr&auml;ver r&auml;ttigheten Advanced File Management)';
$lang['writable'] = 'Skrivbar';
$lang['writeprotected'] = 'Skrivskyddad';
$lang['bytes'] = 'byte';
$lang['kb'] = 'kb ';
$lang['mb'] = 'mb ';
$lang['files'] = 'filer';
$lang['bytesin'] = 'bytes i';
$lang['in'] = 'i';
$lang['file'] = 'fil';
$lang['fileno'] = 'Filnummer';
$lang['subdirs'] = 'underkataloger';
$lang['subdir'] = 'underkatalog';
$lang['and'] = 'och';
$lang['confirmsingledelete'] = '&Auml;r du s&auml;ker?';
$lang['confirmsingledirdelete'] = '&Auml;r du s&auml;ker p&aring; att du vill ta bort den h&auml;r katalogen?';
$lang['dirtreedeletesuccess'] = 'Katalogen och dess inneh&aring;ll togs bort.';
$lang['dirtreedeletefail'] = 'Ett fel uppstod d&aring; den h&auml;r katalogen skulle tas bort. En del av dess inneh&aring;ll kan ha tagits bort.';
$lang['singlefiledeletesuccess'] = 'Filen togs bort';
$lang['filedeletesuccess'] = 'togs bort';
$lang['singlefiledeletefail'] = 'Ett fel uppstod d&aring; filen skulle tas bort';
$lang['filedeletefail'] = ' togs inte bort p&aring; grund av ett fel';
$lang['singledirdeletesuccess'] = 'Katalogen togs bort';
$lang['singledirdeletefail'] = 'Ett fel uppstod d&aring; katalogen skulle tas bort (&auml;r den tom?)';
$lang['deleteselected'] = 'Ta bort de markerade filerna';
$lang['confirmselected'] = '&Auml;r du s&auml;ker?';
$lang['confirmdeleteselected'] = '&Auml;r du s&auml;ker p&aring; att de valda filerna ska tas bort?';
$lang['deleteselectedcancelled'] = 'Borttagning av de valda filerna &aring;ngrad';
$lang['recursetext'] = 'Rekursivt (upprepa) i undermappar';
$lang['nofilesselected'] = 'Inga filer valda';
$lang['moveselected'] = 'Flytta de valda filerna';
$lang['copyselected'] = 'Kopiera de valda filerna';
$lang['selecttargetdir'] = 'V&auml;lj m&aring;lmapp f&ouml;r flytta/kopiera';
$lang['movedto'] = 'flytta till';
$lang['copiedto'] = 'kopiera till';
$lang['couldnotmove'] = 'kunde inte tas bort';
$lang['couldnotcopy'] = 'kunde inte kopieras';
$lang['filesdeletedsuccessfully'] = '%s file(s) har raderats';
$lang['filesdeletedfiled'] = '%s file(s) kunde inte raderas';
$lang['filesmovedsuccessfully'] = '%s file(s) har flyttats';
$lang['filesmovedfailed'] = '%s file(s) kunde inte flyttas';
$lang['filescopiedsuccessfully'] = '%s file(s) har kopierats';
$lang['filescopiedfailed'] = '%s file(s) kunde inte kopieras';
$lang['internalerror'] = 'Internt fel (n&aring;got gick snett, v&auml;nligen rapportera vad du gjorde)';
$lang['rename'] = 'Byt namn';
$lang['newname'] = 'Nytt namn:';
$lang['renamesuccess'] = 'Filen har bytt namn';
$lang['renamefailure'] = 'Byte av filnamn misslyckades';
$lang['renamecancelled'] = 'Byte av filnamn &aring;ngrat';
$lang['owner'] = '&Auml;gare';
$lang['group'] = 'Grupp';
$lang['others'] = 'Andra';
$lang['newpermissions'] = 'Nya r&auml;ttigheter:';
$lang['setpermissions'] = 'St&auml;ll in r&auml;ttigheter';
$lang['permissionstyle'] = 'R&auml;ttighetsstil';
$lang['rwxstyle'] = 'rwx-stil';
$lang['755style'] = '755-stil';
$lang['quickmode'] = 'Snabbt chmod (som 777)';
$lang['chmod'] = 'Byt r&auml;ttigheter';
$lang['chmodselected'] = 'Byt r&auml;ttigheter f&ouml;r valda filer';
$lang['chmodsuccess'] = 'Filen fick nya r&auml;ttigheter';
$lang['chmodfailure'] = 'Byte av r&auml;ttigheter f&ouml;r fil misslyckades';
$lang['chmodcancelled'] = 'Byte av r&auml;ttigheter &aring;ngrat';
$lang['newuploadfailed'] = '%s file(s) gick inte att &ouml;verf&ouml;ra (eller m&ouml;jligen packa upp) ';
$lang['newuploadsuccess'] = '%s file(s) har laddats upp (and unpacked if chosen)';
$lang['dirchmodfailmulti'] = 'Byte av r&auml;ttigheter f&ouml;r mappen misslyckades, n&aring;got av dess inneh&aring;ll kan dock ha f&aring;tt nya r&auml;ttigheter.';
$lang['dirchmodsuccessmulti'] = 'Byte av r&auml;ttigheter f&ouml;r mappen och dess inneh&aring;ll genomf&ouml;rt';
$lang['dirchmodsuccess'] = 'Mappen har f&aring;tt nya r&auml;ttigheter';
$lang['dirchmodfailure'] = 'Byte av r&auml;ttigheter f&ouml;r mappen misslyckades';
$lang['dirnotemptyconfirm'] = 'Den h&auml;r katalogen &auml;r inte tom. Vill du verkligen ta bort allt inneh&aring;ll, inklusive eventuella underkataloger?';
$lang['dirtreedeletecancelled'] = 'Borttagningen avbr&ouml;ts.';
$lang['imsure'] = 'Jag &auml;r s&auml;ker';
$lang['cancel'] = 'Avbryt';
$lang['ok'] = 'Ok';
$lang['uploadnewfile'] = 'Ladda upp ny fil/nya filer:';
$lang['unpackafterupload'] = 'F&ouml;rs&ouml;k packa upp fil efter uppladdning (bara tgz- och flertalet zip-filer)?';
$lang['uploadsuccess'] = 'laddades upp';
$lang['uploadfail'] = 'laddades inte upp';
$lang['unpacksuccess'] = 'packades upp';
$lang['unpackfail'] = 'misslyckades med f&ouml;ljande fel:';
$lang['packfileopenfail'] = 'Kunde inte &ouml;ppna den packade filen. Kontrollera formatet.';
$lang['packfilewritefail'] = 'Kunde inte &ouml;ppna filen &amp;s f&ouml;r skrivning';
$lang['afilecontainsillegalchars'] = 'Ett filnamn inneh&aring;ller en eller flera ogiltiga tecken (&#039;,&quot;,+,*,\,/,&amp;,$).Uppladdningen avbr&ouml;ts.';
$lang['currentpath'] = 'G&auml;llande s&ouml;kv&auml;g:';
$lang['newdirname'] = 'Skapa ny katalog:';
$lang['newdirsuccess'] = 'Katalogen skapades';
$lang['newdirfail'] = 'Ett fel uppstod d&aring; katalogen skulle skapas';
$lang['direxists'] = 'Katalogen finns redan';
$lang['invalidnewdir'] = 'Namn p&aring; nya kataloger kan inte inneh&aring;lla /, \ och &#039;..&#039; ';
$lang['filedateformat'] = 'm/d/&Aring; T:m:s';
$lang['iconsize'] = 'Ikonstorlek';
$lang['smallicons'] = 'Sm&aring; ikoner';
$lang['largeicons'] = 'Stora ikoner';
$lang['thousanddelimiter'] = 'Tusentalsavgr&auml;nsare';
$lang['none'] = 'Inga';
$lang['space'] = 'mellanslag';
$lang['showthumbnails'] = 'Visa tumnaglar';
$lang['showthumbnailshelp'] = 'N&auml;r detta &auml;r aktiverat kommer tumnaglar av bildfiler visas om de finns, och sj&auml;lva tumnagelfilen kommer att d&ouml;ljas. Vid inaktivering visas alla filer.';
$lang['uploadfilesto'] = 'Laddar upp filer till:';
$lang['uploadview'] = 'Ladda upp filer';
$lang['uploadboxes'] = 'Antal uploadboxar';
$lang['nothinguploaded'] = 'Ingenting laddades upp';
$lang['newunsupportedarchive'] = '%s &auml;r ett arkivformat som inte st&ouml;ds';
$lang['uploadmethod'] = 'Uppladdningsmetod';
$lang['uploaderstandard'] = 'Standardmetod f&ouml;r html-inmatning (till&aring;ter uppackning)';
$lang['enableadvanced'] = 'M&ouml;jligg&ouml;r avancerat l&auml;ge?';
$lang['advancedhelp'] = 'L&aring;ter dig f&aring; tillg&aring;ng till CMSMS hela filsystem, inte bara /upload/ (om till&aring;tet)';
$lang['showhiddenfileshelp'] = 'Fungerar bara med avancerat l&auml;ge p&aring;';
$lang['showhiddenfiles'] = 'Visa dolda filer';
$lang['settingsconfirmsingledelete'] = 'Bekr&auml;fta borttaning av enstaka fil?';
$lang['settingssaved'] = 'Inst&auml;llningarna sparades';
$lang['help'] = '		<h3>Vad g&ouml;r den h&auml;r modulen?</h3>
		<p>Den h&auml;r modulen tillhandah&aring;ller funktioner f&ouml;r filhantering.</p>
		<h3>Hur anv&auml;nder jag den?</h3>
		<p>V&auml;ljd den fr&aring;n Inneh&aring;ll i administrationssidan.</p>';
$lang['utma'] = '156861353.1709034040.1299076684.1299076684.1299076684.1';
$lang['utmb'] = '156861353.1.10.1299076684';
$lang['utmc'] = '156861353';
$lang['utmz'] = '156861353.1299076684.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
$lang['qca'] = 'P0-367064362-1299076684445';
?>
